@@ -73,22 +73,27 @@ pub fn run_treefmt(
     // Load the treefmt.toml file
     let project_config = config::from_path(&treefmt_toml)?;
 
+    let global_excludes = project_config
+        .global
+        .map(|g| g.excludes)
+        .unwrap_or_default();
+
     timed_debug("load config");
 
     // Load all the formatter instances from the config. Ignore the ones that failed.
-    let formatters =
-        project_config
-            .formatter
-            .iter()
-            .fold(BTreeMap::new(), |mut sum, (name, fmt_config)| {
-                match Formatter::from_config(&tree_root, &name, &fmt_config) {
-                    Ok(fmt_matcher) => {
-                        sum.insert(fmt_matcher.name.clone(), fmt_matcher);
-                    }
-                    Err(err) => error!("Ignoring formatter #{} due to error: {}", name, err),
-                };
-                sum
-            });
+    let formatters = project_config.formatter.into_iter().fold(
+        BTreeMap::new(),
+        |mut sum, (name, mut fmt_config)| {
+            fmt_config.excludes.extend_from_slice(&global_excludes);
+            match Formatter::from_config(&tree_root, &name, &fmt_config) {
+                Ok(fmt_matcher) => {
+                    sum.insert(fmt_matcher.name.clone(), fmt_matcher);
+                }
+                Err(err) => error!("Ignoring formatter #{} due to error: {}", name, err),
+            };
+            sum
+        },
+    );
 
     timed_debug("load formatters");
 
@@ -127,7 +132,10 @@ pub fn run_treefmt(
         match walk_entry {
             Ok(dir_entry) => {
                 if let Some(file_type) = dir_entry.file_type() {
-                    if !file_type.is_dir() {
+                    // Ignore folders and symlinks. We don't want to format files outside the
+                    // directory, and if the symlink destination is in the repo, it'll be matched
+                    // when iterating over it.
+                    if !file_type.is_dir() && !file_type.is_symlink() {
                         // Keep track of how many files were traversed
                         traversed_files += 1;
 
@@ -331,20 +339,25 @@ pub fn run_treefmt_stdin(
     // Load the treefmt.toml file
     let project_config = config::from_path(&treefmt_toml)?;
 
+    let global_excludes = project_config
+        .global
+        .map(|g| g.excludes)
+        .unwrap_or_default();
+
     // Load all the formatter instances from the config. Ignore the ones that failed.
-    let formatters =
-        project_config
-            .formatter
-            .iter()
-            .fold(BTreeMap::new(), |mut sum, (name, fmt_config)| {
-                match Formatter::from_config(&tree_root, &name, &fmt_config) {
-                    Ok(fmt_matcher) => {
-                        sum.insert(fmt_matcher.name.clone(), fmt_matcher);
-                    }
-                    Err(err) => error!("Ignoring formatter #{} due to error: {}", name, err),
-                };
-                sum
-            });
+    let formatters = project_config.formatter.into_iter().fold(
+        BTreeMap::new(),
+        |mut sum, (name, mut fmt_config)| {
+            fmt_config.excludes.extend_from_slice(&global_excludes);
+            match Formatter::from_config(&tree_root, &name, &fmt_config) {
+                Ok(fmt_matcher) => {
+                    sum.insert(fmt_matcher.name.clone(), fmt_matcher);
+                }
+                Err(err) => error!("Ignoring formatter #{} due to error: {}", name, err),
+            };
+            sum
+        },
+    );
 
     // Collect all formatters that match the path
     let formatters: Vec<&Formatter> = formatters.values().filter(|f| f.is_match(&path)).collect();
